aboutsummaryrefslogtreecommitdiff
path: root/src/qt/bitcoingui.h
diff options
context:
space:
mode:
authorGlenn Willen <gwillen@nerdnet.org>2020-01-31 15:59:57 -0800
committerGlenn Willen <gwillen@nerdnet.org>2020-06-19 02:20:04 -0700
commit11a0ffb29d1b4dcc55c8826873f340ab4196af21 (patch)
tree539263ebb90413fa6aeea3f2c059104b6a92e2b9 /src/qt/bitcoingui.h
parenta6cb0b0c29d327d01aebb98b0504f317eb19c3dc (diff)
downloadbitcoin-11a0ffb29d1b4dcc55c8826873f340ab4196af21.tar.xz
[gui] Load PSBT from clipboard
Diffstat (limited to 'src/qt/bitcoingui.h')
-rw-r--r--src/qt/bitcoingui.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/qt/bitcoingui.h b/src/qt/bitcoingui.h
index b009e279b6..697e83e772 100644
--- a/src/qt/bitcoingui.h
+++ b/src/qt/bitcoingui.h
@@ -139,6 +139,7 @@ private:
QAction* signMessageAction = nullptr;
QAction* verifyMessageAction = nullptr;
QAction* m_load_psbt_action = nullptr;
+ QAction* m_load_psbt_clipboard_action = nullptr;
QAction* aboutAction = nullptr;
QAction* receiveCoinsAction = nullptr;
QAction* receiveCoinsMenuAction = nullptr;
@@ -278,8 +279,8 @@ public Q_SLOTS:
void gotoSignMessageTab(QString addr = "");
/** Show Sign/Verify Message dialog and switch to verify message tab */
void gotoVerifyMessageTab(QString addr = "");
- /** Show load Partially Signed Bitcoin Transaction dialog */
- void gotoLoadPSBT();
+ /** Load Partially Signed Bitcoin Transaction from file or clipboard */
+ void gotoLoadPSBT(bool from_clipboard = false);
/** Show open dialog */
void openClicked();